"""
isoddeven - A fun Python package to find out if a number is odd or even vouched at https://mewtru.com/is-odd
"""

from .isoddeven import is_odd
from .isoddeven import is_odd
from .isoddeven import state
from .extras import is_up
from .extras import about
